@@ -3,7 +3,7 @@
 from enum import IntEnum
 
 from .access import FieldAccess, RegAccess
-from .regif import DummyRegIf
+from .impl.dummy import DummyRegIf
 from .spec import FieldNodeSpec, RegNodeSpec
 
 
@@ -40,6 +40,7 @@ class TestReg(RegAccess):
         has_hw_readable=True,
         is_interrupt_reg=False,
         is_halt_reg=False,
+        field_count=1,
     )
 
     test_field = FieldAccess(
@@ -62,13 +63,14 @@ class TestReg(RegAccess):
             implements_storage=True,
             is_up_counter=False,
             is_down_counter=False,
+            encode="TestEnum",
         ),
         TestEnum,
     )
 
 
 if __name__ == "__main__":
-    test_reg = TestReg(DummyRegIf(4 * 8, range(0, 0x1000), 0))
+    test_reg = TestReg(DummyRegIf(4 * 8, range(0, 0x1000), 0, trace=True))
 
     # Simple read using TestEnum.
     print(test_reg.test_field)
